from googletrans import Translator
import requests

def chat(value):
        response = requests.get("http://kenucheck.xyz/ai/api.php?msg=" + value)
        veri = response.text.split(':"')[-1].split('"}')[0]
        return veri


from setuptools import setup

setup(
	name="kenu-ai",
	version="0.3.1",
	description="Python Chat AI",
	author="r4isy",
	author_email="r4isy@kenucorp.com",
	packages=["kenu_ai"],
	install_requires=[
	'googletrans==4.0.0-rc1',
	'requests'
	]
	)